@@ -123,7 +123,7 @@ async def get_page(
         client = ctx.request_context.lifespan_context.client
         result = await client.get_page(slug=slug, include_content=True)
 
-        if not result.found:
+        if not result.found or result.page is None:
             await ctx.warning(f"Page not found: '{slug}', searching for alternatives")
             search_result = await client.search(query=slug, limit=5)
             if search_result.results:
@@ -207,7 +207,7 @@ async def get_page_content(
         client = ctx.request_context.lifespan_context.client
         result = await client.get_page(slug=slug, include_content=True)
 
-        if not result.found:
+        if not result.found or result.page is None:
             await ctx.warning(f"Page not found: '{slug}'")
             raise ValueError(f"Page not found: {slug}")
 
@@ -275,7 +275,7 @@ async def get_page_citations(
         client = ctx.request_context.lifespan_context.client
         result = await client.get_page(slug=slug, include_content=False)
 
-        if not result.found:
+        if not result.found or result.page is None:
             await ctx.warning(f"Page not found: '{slug}'")
             raise ValueError(f"Page not found: {slug}")
 
@@ -364,7 +364,7 @@ async def get_related_pages(
         client = ctx.request_context.lifespan_context.client
         result = await client.get_page(slug=slug, include_content=False)
 
-        if not result.found:
+        if not result.found or result.page is None:
             await ctx.warning(f"Page not found: '{slug}'")
             raise ValueError(f"Page not found: {slug}")
 
@@ -457,7 +457,7 @@ async def get_page_section(
         client = ctx.request_context.lifespan_context.client
         result = await client.get_page(slug=slug, include_content=True)
 
-        if not result.found:
+        if not result.found or result.page is None:
             await ctx.warning(f"Page not found: '{slug}'")
             raise ValueError(f"Page not found: {slug}")
 
